# AUTOGENERATED! DO NOT EDIT! File to edit: ../00_core.ipynb.

# %% auto 0
__all__ = ['say_hello', 'say_bye', 'HelloSayer']

# %% ../00_core.ipynb 3
def say_hello(to):
    "Say hello to somebody"
    return f'Hello {to}!'

# %% ../00_core.ipynb 6
def say_bye(to):
    "Say bye to somebody"
    return f'Bye {to}!'

# %% ../00_core.ipynb 7
class HelloSayer:
    "Say hello to `to` using `say_hello`"
    def __init__(self, to): self.to = to
        
    def say(self):
        "Do the saying"
        return say_hello(self.to)



# Autogenerated by nbdev

d = { 'settings': { 'audience': 'Developers',
                'author': 'João Nogueira',
                'author_email': 'joao.nogueira@datarisk.io',
                'branch': 'main',
                'copyright': 'Put your copyright info here',
                'custom_sidebar': 'False',
                'description': 'lorem ipsum',
                'doc_baseurl': '/neoinfo_nbdev/',
                'doc_host': 'https://joaopcnogueira.github.io',
                'doc_path': '_docs',
                'git_url': 'https://github.com/joaopcnogueira/neoinfo-nbdev/',
                'host': 'github',
                'keywords': 'nbdev',
                'language': 'English',
                'lib_name': 'neoinfo_nbdev',
                'lib_path': 'neoinfo_nbdev',
                'license': 'apache2',
                'min_python': '3.8',
                'nbs_path': '.',
                'recursive': 'False',
                'repo': 'neoinfo-nbdev',
                'status': '2',
                'title': 'neoinfo_nbdev',
                'tst_flags': 'notest',
                'user': 'joaopcnogueira',
                'version': '0.0.1'},
  'syms': { 'neoinfo_nbdev.core': { 'neoinfo_nbdev.core.HelloSayer': 'https://joaopcnogueira.github.io/neoinfo_nbdev/core.html#hellosayer',
                                    'neoinfo_nbdev.core.HelloSayer.say': 'https://joaopcnogueira.github.io/neoinfo_nbdev/core.html#hellosayer.say',
                                    'neoinfo_nbdev.core.say_bye': 'https://joaopcnogueira.github.io/neoinfo_nbdev/core.html#say_bye',
                                    'neoinfo_nbdev.core.say_hello': 'https://joaopcnogueira.github.io/neoinfo_nbdev/core.html#say_hello'}}}